//
//  CourseModel.swift
//  TeachMate
//
//  Created by Hongli on 2025/3/13.
//

import Foundation
import SwiftData
import SwiftUI
import Observation

@SwiftData.Model
final class ClassSession {
    var weekday: Int // 1-7 表示周一到周日
    var timeSlot: Int // 1-5 表示不同的时间段
    var location: String
    var schoolCalss: String
    var course: CourseModel?
    
    init(weekday: Int, timeSlot: Int, location: String, schoolClass: String) {
        self.weekday = weekday
        self.timeSlot = timeSlot
        self.location = location
        self.schoolCalss = schoolClass
    }
}

@SwiftData.Model
final class CourseModel {
    var name: String
    @Relationship(deleteRule: .cascade, inverse: \ClassSession.course)
    var sessions: [ClassSession] = []
    var colorHex: String
    var semester: Semester?
    
    init(name: String, colorHex: String, isNew: Bool = false) {
        self.name = name
        self.colorHex = colorHex
    }
    
    // Convenience initializer for backward compatibility
    convenience init(name: String, location: String, weekday: Int, timeSlot: Int, colorHex: String, isNew: Bool = false, schoolClass: String) {
        self.init(name: name, colorHex: colorHex, isNew: isNew)
        let session = ClassSession(weekday: weekday, timeSlot: timeSlot, location: location, schoolClass: schoolClass)
        self.sessions.append(session)
        session.course = self
    }
    
    var backgroundColor: Color {
        Color(hex: colorHex) ?? Color.gray.opacity(0.3)
    }
    
    // Helper method to add a new class session
    func addSession(weekday: Int, timeSlot: Int, location: String, schoolClass: String) {
        let session = ClassSession(weekday: weekday, timeSlot: timeSlot, location: location, schoolClass: schoolClass)
        sessions.append(session)
        session.course = self
    }
}
